==> cscec5b-rmat-impl-3.0.1-20230609.071328-202-sources.jar: com/ejianc/business/rmat/bean/ContInfoPriceRecordEntity.java <==
package com.ejianc.business.rmat.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.math.BigDecimal;
import java.util.Date;

/**
 * 周转材合同清单价格记录
 *
 * @author generator
 *
 */
 @TableName("ejc_rmat_price_record")
public class ContInfoPriceRecordEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    //合同主键
    @TableField(value="pk_contract")
    private String pkContract;
    //变更日期
    @TableField(value="dmakedate")
    private Date dmakedate;
    //清单主键
    @TableField(value="pk_leaselist")
    private String pkLeaselist;
    //合同分录Pk
    @TableField(value="pk_amountlist")
    private String pkAmountlist;
    //修订单价
    @TableField(value="nhireprice")
    private BigDecimal nhireprice;
    //生效日期
    @TableField(value="dactivedate")
    private Date dactivedate;
    //更新时间
    @TableField(value="ts")
    private Date ts;


    public String getPkContract() {
        return pkContract;
    }

    public void setPkContract(String pkContract) {
        this.pkContract = pkContract;
    }

    public Date getDmakedate() {
        return dmakedate;
    }

    public void setDmakedate(Date dmakedate) {
        this.dmakedate = dmakedate;
    }

    public String getPkLeaselist() {
        return pkLeaselist;
    }

    public void setPkLeaselist(String pkLeaselist) {
        this.pkLeaselist = pkLeaselist;
    }

    public String getPkAmountlist() {
        return pkAmountlist;
    }

    public void setPkAmountlist(String pkAmountlist) {
        this.pkAmountlist = pkAmountlist;
    }

    public BigDecimal getNhireprice() {
        return nhireprice;
    }

    public void setNhireprice(BigDecimal nhireprice) {
        this.nhireprice = nhireprice;
    }

    public Date getDactivedate() {
        return dactivedate;
    }

    public void setDactivedate(Date dactivedate) {
        this.dactivedate = dactivedate;
    }

    public Date getTs() {
        return ts;
    }

    public void setTs(Date ts) {
        this.ts = ts;
    }
}

==> cscec5b-rmat-impl-3.0.1-20250120.095631-338-sources.jar: com/ejianc/business/rmat/bean/ContInfoPriceRecordEntity.java <==
package com.ejianc.business.rmat.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.math.BigDecimal;
import java.util.Date;

/**
 * 周转材合同清单价格记录
 *
 * @author generator
 *
 */
 @TableName("ejc_rmat_price_record")
public class ContInfoPriceRecordEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    //合同主键
    @TableField(value="pk_contract")
    private String pkContract;
    //变更日期
    @TableField(value="dmakedate")
    private Date dmakedate;
    //清单主键
    @TableField(value="pk_leaselist")
    private String pkLeaselist;
    //合同分录Pk
    @TableField(value="pk_amountlist")
    private String pkAmountlist;
    //修订单价
    @TableField(value="nhireprice")
    private BigDecimal nhireprice;
    //生效日期
    @TableField(value="dactivedate")
    private Date dactivedate;
    //更新时间
    @TableField(value="ts")
    private Date ts;
    //期初录入
    @TableField(value="period_flag")
    private Boolean periodFlag;
    //验收录入
    @TableField(value="check_flag")
    private Boolean checkFlag;


    public String getPkContract() {
        return pkContract;
    }

    public void setPkContract(String pkContract) {
        this.pkContract = pkContract;
    }

    public Date getDmakedate() {
        return dmakedate;
    }

    public void setDmakedate(Date dmakedate) {
        this.dmakedate = dmakedate;
    }

    public String getPkLeaselist() {
        return pkLeaselist;
    }

    public void setPkLeaselist(String pkLeaselist) {
        this.pkLeaselist = pkLeaselist;
    }

    public String getPkAmountlist() {
        return pkAmountlist;
    }

    public void setPkAmountlist(String pkAmountlist) {
        this.pkAmountlist = pkAmountlist;
    }

    public BigDecimal getNhireprice() {
        return nhireprice;
    }

    public void setNhireprice(BigDecimal nhireprice) {
        this.nhireprice = nhireprice;
    }

    public Date getDactivedate() {
        return dactivedate;
    }

    public void setDactivedate(Date dactivedate) {
        this.dactivedate = dactivedate;
    }

    public Date getTs() {
        return ts;
    }

    public void setTs(Date ts) {
        this.ts = ts;
    }

    public Boolean getPeriodFlag() {
        return periodFlag;
    }

    public void setPeriodFlag(Boolean periodFlag) {
        this.periodFlag = periodFlag;
    }

    public Boolean getCheckFlag() {
        return checkFlag;
    }

    public void setCheckFlag(Boolean checkFlag) {
        this.checkFlag = checkFlag;
    }
}
